/******************************************************************************
*
* project name: TI-MineSweeper
* filename:     counter.c
* initial date: 03/07/2000
* authors:      thomas.nussbaumer@gmx.net (coding)
*               marcos.lopez@wol.es (game play/graphics/BETA testing)
* description:  handling of a 3 digit counter with width=6 and height=15
*
* IMPORTANT: graymode must be already on before calling InitCounter()
*
*
* Current implementation uses TIGCC 0.95 Beta 12
*
* $Id: counter.c,v 1.3 2004/07/14 15:08:58 DEBROUX Lionel Exp $
*
******************************************************************************/

#include "extgraph.h"
#include "timiner.h"

unsigned char numbers_plane1[15*10]={
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //0
0xfe,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //1
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfe, //2
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //3
0xfe,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //4
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //5
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //6
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //7
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //8
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe};//9

unsigned char numbers_plane2[15*10]={
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //0
0xfe,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //1
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfe, //2
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //3
0xfe,0xfe,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //4
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe, //5
0xfe,0xc6,0xbe,0xbe,0xbe,0xbe,0xbe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //6
0xfe,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfa,0xfa,0xfa,0xfa,0xfa,0xfe,0xfe, //7
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfe, //8
0xfe,0xc6,0xba,0xba,0xba,0xba,0xba,0xc6,0xfa,0xfa,0xfa,0xfa,0xfa,0xc6,0xfe};//9

unsigned char cleaner[15] = {
0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01};


/*===========================================================================*/
/* updates counter display                                                   */
/*===========================================================================*/
void UpdateCounter(counter_t *p) {
    char tmp[3];
    short value = p->value;
    short i;

    if (value > 999) value = 999;
    if (value < 0)   value = 0;

    for (i=2;i>=0;i--) {
        tmp[i] = value % 10;
        value /= 10;
    }

    for (i=0;i<3;i++) {
        if (firsttime || tmp[i] != p->digits[i]) {
            short real_x       = p->xpos + i*NUMBER_WIDTH;
            short digit_offset = NUMBER_OFFSET*tmp[i];
            GraySprite8_MASK_R(real_x,bc_ypos,NUMBER_HEIGHT,
                    numbers_plane1+digit_offset,numbers_plane2+digit_offset,
                    cleaner,cleaner,GetPlane(LIGHT_PLANE),GetPlane(DARK_PLANE));
            p->digits[i] = tmp[i];
        }
    }
}


//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: counter.c,v $
// Revision 1.3  2004/07/14 15:08:58  DEBROUX Lionel
// recompiled with TIGCC 0.95 Beta 12
//
// Revision 1.2  2004/07/11 16:45:03  DEBROUX Lionel
// generic commit
//
// Revision 1.1  2002/09/27 10:10:30  tnussb
// initial check-in to CVS repository
//
//
